@@ -60,7 +60,7 @@ PERFORMANCE OF THIS SOFTWARE.
 #include "XimTrInt.h"
 #include "XimTrX.h"
 
-Private Bool
+static Bool
 _XimXRegisterDispatcher(
     Xim			 im,
     Bool		 (*callback)(
@@ -71,7 +71,7 @@ _XimXRegisterDispatcher(
     XIntrCallbackPtr	 rec;
     XSpecRec		*spec = (XSpecRec *)im->private.proto.spec;
 
-    if (!(rec = (XIntrCallbackPtr)Xmalloc(sizeof(XIntrCallbackRec))))
+    if (!(rec = Xmalloc(sizeof(XIntrCallbackRec))))
         return False;
 
     rec->func       = callback;
@@ -81,7 +81,7 @@ _XimXRegisterDispatcher(
     return True;
 }
 
-Private void
+static void
 _XimXFreeIntrCallback(
     Xim			 im)
 {
@@ -93,10 +93,11 @@ _XimXFreeIntrCallback(
 	Xfree(rec);
 	rec = next;
     }
+    spec->intr_cb = NULL;
     return;
 }
 
-Private Bool
+static Bool
 _XimXCallDispatcher(Xim im, INT16 len, XPointer data)
 {
     register XIntrCallbackRec	*rec;
@@ -109,7 +110,7 @@ _XimXCallDispatcher(Xim im, INT16 len, XPointer data)
     return False;
 }
 
-Private Bool
+static Bool
 _XimXFilterWaitEvent(
     Display	*d,
     Window	 w,
@@ -137,7 +138,7 @@ _XimXFilterWaitEvent(
      return ret;
 }
 
-Private Bool
+static Bool
 _CheckConnect(
     Display	*display,
     XEvent	*event,
@@ -153,7 +154,7 @@ _CheckConnect(
     return False;
 }
 
-Private Bool
+static Bool
 _XimXConnect(Xim im)
 {
     XEvent	 event;
@@ -224,7 +225,7 @@ _XimXConnect(Xim im)
     return True;
 }
 
-Private Bool
+static Bool
 _XimXShutdown(Xim im)
 {
     XSpecRec	*spec = (XSpecRec *)im->private.proto.spec;
@@ -244,7 +245,7 @@ _XimXShutdown(Xim im)
     return True;
 }
 
-Private char *
+static char *
 _NewAtom(
     char	*atomName)
 {
@@ -255,7 +256,7 @@ _NewAtom(
     return atomName;
 }
 
-Private Bool
+static Bool
 _XimXWrite(Xim im, INT16 len, XPointer data)
 {
     Atom	 atom;
@@ -316,7 +317,7 @@ _XimXWrite(Xim im, INT16 len, XPointer data)
     return True;
 }
 
-Private Bool
+static Bool
 _XimXGetReadData(
     Xim			  im,
     char		 *buf,
@@ -372,7 +373,7 @@ _XimXGetReadData(
 		XFree(prop_ret);
 	    return False;
 	}
-	if (buf_len >= length) {
+	if (buf_len >= (int)nitems) {
 	    (void)memcpy(buf, prop_ret, (int)nitems);
 	    *ret_len  = (int)nitems;
 	    if (bytes_after_ret > 0) {
@@ -440,7 +441,7 @@ _XimXGetReadData(
     return True;
 }
 
-Private Bool
+static Bool
 _CheckCMEvent(
     Display	*display,
     XEvent	*event,
@@ -461,7 +462,7 @@ _CheckCMEvent(
     return False;
 }
 
-Private Bool
+static Bool
 _XimXRead(Xim im, XPointer recv_buf, int buf_len, int *ret_len)
 {
     XEvent	*ev;
@@ -484,14 +485,14 @@ _XimXRead(Xim im, XPointer recv_buf, int buf_len, int *ret_len)
     return True;
 }
 
-Private void
+static void
 _XimXFlush(Xim im)
 {
     XFlush(im->core.display);
     return;
 }
 
-Public Bool
+Bool
 _XimXConf(Xim im, char *address)
 {
     XSpecRec	*spec;
