@@ -323,7 +323,7 @@ _XlcParseCharSet(
     if (*ptr == '\0')
     	return False;
 
-    length = strlen(ptr);
+    length = (int) strlen(ptr);
 
     type = _XlcParseCT(&ptr, &length, &final_byte);
 
@@ -428,7 +428,7 @@ _XlcGetCTInfo(
             && (type != XctExtSeg
                 || (text_len >= ct_info->ext_segment_len
                     && memcmp(text, ct_info->ext_segment,
-                              ct_info->ext_segment_len) == 0)))
+                              (size_t) ct_info->ext_segment_len) == 0)))
             return ct_info;
 
     return (CTInfo) NULL;
@@ -477,8 +477,8 @@ _XlcAddCT(
     }
 
     /* Allocate a CTinfo record. */
-    length = strlen(ct_sequence);
-    ct_info = (CTInfo) Xmalloc(sizeof(CTInfoRec) + length+1);
+    length = (int) strlen(ct_sequence);
+    ct_info = Xmalloc(sizeof(CTInfoRec) + length+1);
     if (ct_info == NULL)
 	return charset;
 
@@ -506,7 +506,7 @@ _XlcAddCT(
             /* By convention, the extended segment name is the encoding_name
                in lowercase. */
             const char *q = charset->encoding_name;
-            int n = strlen(q);
+            int n = (int) strlen(q);
             char *p;
 
             /* Ensure ct_info->ext_segment_len <= 0x3fff - 6. */
@@ -514,7 +514,7 @@ _XlcAddCT(
                 Xfree(ct_info);
                 return charset;
             }
-            p = (char *) Xmalloc(n+1);
+            p = Xmalloc(n+1);
             if (p == NULL) {
                 Xfree(ct_info);
                 return charset;
@@ -802,7 +802,7 @@ cttocs(
                 int n = (state->ext_seg_left <= buf_len
                          ? state->ext_seg_left
                          : (buf_len / char_size) * char_size);
-                memcpy(bufptr, ctptr, n);
+                memcpy(bufptr, ctptr, (size_t) n);
                 ctptr += n; ctext_len -= n;
                 bufptr += n; buf_len -= n;
                 state->ext_seg_left -= n;
@@ -834,7 +834,7 @@ cttocs(
                        We may be splitting a character into multiple pieces.
                        Oh well. */
                     int n = buf_len;
-                    memcpy(bufptr, ctptr, n);
+                    memcpy(bufptr, ctptr, (size_t) n);
                     ctptr += n; ctext_len -= n;
                     bufptr += n; buf_len -= n;
                     state->ext_seg_left -= n;
@@ -899,7 +899,7 @@ cstoct(
 	return -1;
 
     side = charset->side;
-    length = strlen(ct_info->ct_sequence);
+    length = (int) strlen(ct_info->ct_sequence);
 
     ext_segment_start = NULL;
 
@@ -909,7 +909,7 @@ cstoct(
         if (ct_len < length + 3)
             return -1;
 
-        memcpy(ctptr, ct_info->ct_sequence, length);
+        memcpy(ctptr, ct_info->ct_sequence, (size_t) length);
         ctptr += length;
         ct_len -= length + 3;
     } else
@@ -924,7 +924,7 @@ cstoct(
             if (ct_len < length + 2 + ct_info->ext_segment_len)
                 return -1;
 
-            memcpy(ctptr, ct_info->ct_sequence, length);
+            memcpy(ctptr, ct_info->ct_sequence, (size_t) length);
             ctptr += length;
             ct_len -= length;
 
@@ -936,14 +936,14 @@ cstoct(
             if (ct_len > 0x3fff)
                 ct_len = 0x3fff;
 
-            memcpy(ctptr, ct_info->ext_segment, ct_info->ext_segment_len);
+            memcpy(ctptr, ct_info->ext_segment, (size_t) ct_info->ext_segment_len);
             ctptr += ct_info->ext_segment_len;
             ct_len -= ct_info->ext_segment_len;
         } else {
             if (ct_len < length)
                 return -1;
 
-            memcpy(ctptr, ct_info->ct_sequence, length);
+            memcpy(ctptr, ct_info->ct_sequence, (size_t) length);
             ctptr += length;
             ct_len -= length;
         }
@@ -970,7 +970,7 @@ cstoct(
 		/* The CompoundText specification says that the only
 		   control characters allowed are 0x09, 0x0a, 0x1b, 0x9b.
 		   Therefore here we eliminate other control characters. */
-		unsigned char ch = *((unsigned char *) csptr) & 0x7f;
+		unsigned char ch = *((const unsigned char *) csptr) & 0x7f;
 		if (!((ch >= min_ch && ch <= max_ch)
 		      || (side == XlcGL
 			  && (ch == 0x00 || ch == 0x09 || ch == 0x0a))
@@ -1020,20 +1020,20 @@ cstoct(
 #endif
            ) {
             while (csstr_len > 0 && ct_len > 0) {
-                unsigned char ch = * (unsigned char *) csptr;
-                int char_size = (ch < 0xc0 ? 1 :
+                unsigned char ch = * (const unsigned char *) csptr;
+                int ch_size = (ch < 0xc0 ? 1 :
                                  ch < 0xe0 ? 2 :
                                  ch < 0xf0 ? 3 :
                                  ch < 0xf8 ? 4 :
                                  ch < 0xfc ? 5 :
                                              6);
                 int i;
-                if (!(csstr_len >= char_size && ct_len >= char_size))
+                if (!(csstr_len >= ch_size && ct_len >= ch_size))
                     break;
-                for (i = char_size; i > 0; i--)
+                for (i = ch_size; i > 0; i--)
                     *ctptr++ = *csptr++;
-                csstr_len -= char_size;
-                ct_len -= char_size;
+                csstr_len -= ch_size;
+                ct_len -= ch_size;
             }
         } else {
             while (csstr_len > 0 && ct_len > 0) {
@@ -1093,9 +1093,9 @@ strtocs(
     dst = (char *) *to;
 
     length = min(*from_left, *to_left);
-    side = *((unsigned char *) src) & 0x80;
+    side = *((const unsigned char *) src) & 0x80;
 
-    while (side == (*((unsigned char *) src) & 0x80) && length-- > 0)
+    while (side == (*((const unsigned char *) src) & 0x80) && length-- > 0)
 	*dst++ = *src++;
 
     *from_left -= src - (const char *) *from;
@@ -1140,7 +1140,7 @@ cstostr(
     str_len = *to_left;
 
     while (csstr_len > 0 && str_len > 0) {
-	ch = *((unsigned char *) csptr++);
+	ch = *((const unsigned char *) csptr++);
 	csstr_len--;
 	/* Citing ICCCM: "STRING as a type specifies the ISO Latin-1 character
 	   set plus the control characters TAB and NEWLINE." */
@@ -1169,7 +1169,7 @@ create_conv(
 {
     XlcConv conv;
 
-    conv = (XlcConv) Xmalloc(sizeof(XlcConvRec) + sizeof(StateRec));
+    conv = Xmalloc(sizeof(XlcConvRec) + sizeof(StateRec));
     if (conv == NULL)
 	return (XlcConv) NULL;
 
@@ -1187,7 +1187,7 @@ close_converter(
     XlcConv conv)
 {
     /* conv->state is allocated together with conv, free both at once.  */
-    Xfree((char *) conv);
+    Xfree(conv);
 }
 
 
