@@ -1015,7 +1015,7 @@ ucstocs1(
     XPointer *args,
     int num_args)
 {
-    ucs4_t const *src = (ucs4_t const *) *from;
+    ucs4_t const *src;
     unsigned char *dst = (unsigned char *) *to;
     int unconv_num = 0;
     Utf8Conv *preferred_charsets = (Utf8Conv *) conv->state;
@@ -1027,6 +1027,8 @@ ucstocs1(
     if (from == NULL || *from == NULL)
 	return 0;
 
+    src = (ucs4_t const *) *from;
+
     count = charset_wctocs_exactly(preferred_charsets, &chosen_charset,
                                    &chosen_side, conv, dst, *src, *to_left);
     if (count < 1) {
@@ -1725,7 +1727,7 @@ create_tofontcs_conv(
 {
     XlcConv conv;
     int i, num, k, count;
-    char **value, buf[20];
+    char **value, buf[32];
     Utf8Conv *preferred;
 
     lazy_init_all_charsets();
@@ -1932,7 +1934,7 @@ iconv_mbstocs(XlcConv conv, XPointer *from, int *from_left,
 
     /* Uses stdc iconv to convert multibyte -> widechar */
 
-	consumed = mbtowc(&wc, (const char *)src, srcend-src);
+	consumed = mbtowc(&wc, (const char *)src, (size_t) (srcend - src));
 	if (consumed == 0)
 	    break;
 	if (consumed == -1) {
@@ -2028,7 +2030,7 @@ iconv_mbtocs(XlcConv conv, XPointer *from, int *from_left,
 
     /* Uses stdc iconv to convert multibyte -> widechar */
 
-	consumed = mbtowc(&wc, (const char *)src, srcend-src);
+	consumed = mbtowc(&wc, (const char *)src, (size_t) (srcend - src));
 	if (consumed == 0)
 	    break;
 	if (consumed == -1) {
@@ -2118,7 +2120,7 @@ iconv_mbstostr(XlcConv conv, XPointer *from, int *from_left,
 
     /* Uses stdc iconv to convert multibyte -> widechar */
 
-	consumed = mbtowc(&wc, (const char *)src, srcend-src);
+	consumed = mbtowc(&wc, (const char *)src, (size_t) (srcend - src));
 	if (consumed == 0)
 	    break;
 	if (dst == dstend)
@@ -2222,7 +2224,7 @@ iconv_mbstowcs(XlcConv conv, XPointer *from, int *from_left,
     int length, unconv_num = 0;
 
     while (src_left > 0 && dst_left > 0) {
-	length = mbtowc(dst, src, src_left);
+	length = mbtowc(dst, src, (size_t) src_left);
 
 	if (length > 0) {
 	    src += length;
